﻿using System;
using System.Collections.Generic;
using System.DirectoryServices;
using System.DirectoryServices.AccountManagement;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace LdapImport
{
    internal class Connection
    {
        private string domain;
        private string user;
        private string password;


        internal Connection(string domain, string user, string password)
        {
            this.domain = domain;
            this.user = user;
            this.password = password;
        }

        internal bool Test()
        {
            string userPrincipalName = $"{user}@{domain}";

            try
            {
                using (var context = new PrincipalContext(ContextType.Domain, domain))
                {
                    return context.ValidateCredentials(userPrincipalName, password);
                }
            }
            catch
            {
                return false;
            }
        }

        internal List<User> SearchUsers(string groupName, bool searchLocked)
        {
            var list = new List<User>();

            using (var context = new PrincipalContext(ContextType.Domain, domain, user, password))
            {
                var group = GroupPrincipal.FindByIdentity(context, groupName);

                if (group != null)
                {
                    foreach (Principal p in group.GetMembers())
                    {
                        var theUser = p as UserPrincipal;

                        if (theUser != null)
                        {
                            if (theUser.Enabled.Value || (!theUser.Enabled.Value && searchLocked))
                            {
                                var u = new User();
                                u.SamAccountName = theUser.SamAccountName;
                                u.FirstName = theUser.GivenName;
                                u.LastName = theUser.Surname;
                                list.Add(u);
                            }
                        }
                    }
                }
            }

            return list;
        }

    }
}
